@@ -1,13 +1,13 @@
 /*
  * pluma-changecase-plugin.c
- * 
+ *
  * Copyright (C) 2004-2005 - Paolo Borelli
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -33,19 +33,8 @@
 #include <pluma/pluma-window.h>
 #include <pluma/pluma-debug.h>
 
-#define PLUMA_CHANGECASE_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-					            PLUMA_TYPE_CHANGECASE_PLUGIN, \
-					            PlumaChangecasePluginPrivate))
-
 static void peas_activatable_iface_init (PeasActivatableInterface *iface);
 
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaChangecasePlugin,
-                                pluma_changecase_plugin,
-                                PEAS_TYPE_EXTENSION_BASE,
-                                0,
-                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
-                                                               peas_activatable_iface_init))
-
 struct _PlumaChangecasePluginPrivate
 {
 	GtkWidget        *window;
@@ -54,6 +43,14 @@ struct _PlumaChangecasePluginPrivate
 	guint             ui_id;
 };
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaChangecasePlugin,
+                                pluma_changecase_plugin,
+                                PEAS_TYPE_EXTENSION_BASE,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (PlumaChangecasePlugin)
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
+                                                               peas_activatable_iface_init))
+
 enum {
 	PROP_0,
 	PROP_OBJECT
@@ -280,7 +277,7 @@ pluma_changecase_plugin_init (PlumaChangecasePlugin *plugin)
 {
 	pluma_debug_message (DEBUG_PLUGINS, "PlumaChangecasePlugin initializing");
 
-	plugin->priv = PLUMA_CHANGECASE_PLUGIN_GET_PRIVATE (plugin);
+	plugin->priv = pluma_changecase_plugin_get_instance_private (plugin);
 }
 
 static void
@@ -388,11 +385,11 @@ pluma_changecase_plugin_activate (PeasActivatable *activatable)
 	manager = pluma_window_get_ui_manager (window);
 
 	data->action_group = gtk_action_group_new ("PlumaChangecasePluginActions");
-	gtk_action_group_set_translation_domain (data->action_group, 
+	gtk_action_group_set_translation_domain (data->action_group,
 						 GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (data->action_group,
 				      action_entries,
-				      G_N_ELEMENTS (action_entries), 
+				      G_N_ELEMENTS (action_entries),
 				      window);
 
 	gtk_ui_manager_insert_action_group (manager, data->action_group, -1);
@@ -446,8 +443,6 @@ pluma_changecase_plugin_class_init (PlumaChangecasePluginClass *klass)
 	object_class->get_property = pluma_changecase_plugin_get_property;
 
 	g_object_class_override_property (object_class, PROP_OBJECT, "object");
-
-	g_type_class_add_private (klass, sizeof (PlumaChangecasePluginPrivate));
 }
 
 static void
