@@ -1,13 +1,13 @@
 /*
  * pluma-docinfo-plugin.c
- * 
- * Copyright (C) 2002-2005 Paolo Maggi 
+ *
+ * Copyright (C) 2002-2005 Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -39,19 +39,8 @@
 
 #define MENU_PATH "/MenuBar/ToolsMenu/ToolsOps_2"
 
-#define PLUMA_DOCINFO_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-					         PLUMA_TYPE_DOCINFO_PLUGIN, \
-					         PlumaDocInfoPluginPrivate))
-
 static void peas_activatable_iface_init (PeasActivatableInterface *iface);
 
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaDocInfoPlugin,
-                                pluma_docinfo_plugin,
-                                PEAS_TYPE_EXTENSION_BASE,
-                                0,
-                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
-                                                               peas_activatable_iface_init))
-
 typedef struct
 {
 	GtkWidget *dialog;
@@ -79,6 +68,14 @@ struct _PlumaDocInfoPluginPrivate
 	DocInfoDialog *dialog;
 };
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaDocInfoPlugin,
+                                pluma_docinfo_plugin,
+                                PEAS_TYPE_EXTENSION_BASE,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (PlumaDocInfoPlugin)
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
+                                                               peas_activatable_iface_init))
+
 enum {
 	PROP_0,
 	PROP_OBJECT
@@ -161,7 +158,7 @@ get_docinfo_dialog (PlumaDocInfoPlugin *plugin)
 					 GTK_RESPONSE_OK);
 	gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
 				      GTK_WINDOW (window));
-	
+
 	g_signal_connect (dialog->dialog,
 			  "destroy",
 			  G_CALLBACK (docinfo_dialog_destroy_cb),
@@ -175,15 +172,15 @@ get_docinfo_dialog (PlumaDocInfoPlugin *plugin)
 	return dialog;
 }
 
-static void 
+static void
 calculate_info (PlumaDocument *doc,
 		GtkTextIter   *start,
-		GtkTextIter   *end, 
+		GtkTextIter   *end,
 		gint          *chars,
 		gint          *words,
 		gint          *white_chars,
 		gint          *bytes)
-{	
+{
 	gchar *text;
 
 	pluma_debug (DEBUG_PLUGINS);
@@ -313,7 +310,7 @@ selectioninfo_real (PlumaDocument *doc,
 	if (sel)
 	{
 		lines = gtk_text_iter_get_line (&end) - gtk_text_iter_get_line (&start) + 1;
-	
+
 		calculate_info (doc,
 				&start, &end,
 				&chars, &words, &white_chars, &bytes);
@@ -383,15 +380,15 @@ docinfo_cb (GtkAction	*action,
 
 		dialog = get_docinfo_dialog (plugin);
 		g_return_if_fail (dialog != NULL);
-		
+
 		data->dialog = dialog;
 
 		gtk_widget_show (GTK_WIDGET (dialog->dialog));
 	}
-	
-	docinfo_real (doc, 
-		      data->dialog);	
-	selectioninfo_real (doc, 
+
+	docinfo_real (doc,
+		      data->dialog);
+	selectioninfo_real (doc,
 			    data->dialog);
 }
 
@@ -419,18 +416,18 @@ docinfo_dialog_response_cb (GtkDialog	*widget,
 		case GTK_RESPONSE_OK:
 		{
 			PlumaDocument *doc;
-			
+
 			pluma_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_OK");
-			
+
 			doc = pluma_window_get_active_document (window);
 			g_return_if_fail (doc != NULL);
-			
+
 			docinfo_real (doc,
 				      data->dialog);
 
 			selectioninfo_real (doc,
 					    data->dialog);
-			
+
 			break;
 		}
 	}
@@ -473,7 +470,7 @@ pluma_docinfo_plugin_init (PlumaDocInfoPlugin *plugin)
 {
 	pluma_debug_message (DEBUG_PLUGINS, "PlumaDocInfoPlugin initializing");
 
-	plugin->priv = PLUMA_DOCINFO_PLUGIN_GET_PRIVATE (plugin);
+	plugin->priv = pluma_docinfo_plugin_get_instance_private (plugin);
 }
 
 static void
@@ -545,7 +542,7 @@ pluma_docinfo_plugin_activate (PeasActivatable *activatable)
 	PlumaDocInfoPluginPrivate *data;
 	PlumaWindow *window;
 	GtkUIManager *manager;
-	
+
 	pluma_debug (DEBUG_PLUGINS);
 
 	plugin = PLUMA_DOCINFO_PLUGIN (activatable);
@@ -554,8 +551,8 @@ pluma_docinfo_plugin_activate (PeasActivatable *activatable)
 
 	data->dialog = NULL;
 	data->ui_action_group = gtk_action_group_new ("PlumaDocInfoPluginActions");
-	
-	gtk_action_group_set_translation_domain (data->ui_action_group, 
+
+	gtk_action_group_set_translation_domain (data->ui_action_group,
 						 GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (data->ui_action_group,
 				      action_entries,
@@ -569,12 +566,12 @@ pluma_docinfo_plugin_activate (PeasActivatable *activatable)
 
 	data->ui_id = gtk_ui_manager_new_merge_id (manager);
 
-	gtk_ui_manager_add_ui (manager, 
-			       data->ui_id, 
+	gtk_ui_manager_add_ui (manager,
+			       data->ui_id,
 			       MENU_PATH,
-			       "DocumentStatistics", 
 			       "DocumentStatistics",
-			       GTK_UI_MANAGER_MENUITEM, 
+			       "DocumentStatistics",
+			       GTK_UI_MANAGER_MENUITEM,
 			       FALSE);
 
 	update_ui (data);
@@ -618,8 +615,6 @@ pluma_docinfo_plugin_class_init (PlumaDocInfoPluginClass *klass)
 	object_class->get_property = pluma_docinfo_plugin_get_property;
 
 	g_object_class_override_property (object_class, PROP_OBJECT, "object");
-
-	g_type_class_add_private (klass, sizeof (PlumaDocInfoPluginPrivate));
 }
 
 static void
