@@ -1,14 +1,14 @@
 /*
  * pluma-modeline-plugin.c
  * Emacs, Kate and Vim-style modelines support for pluma.
- * 
+ *
  * Copyright (C) 2005-2007 - Steve Frécinaux <code@istique.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
- 
+
 #ifdef HAVE_CONFIG_H
 #	include <config.h>
 #endif
@@ -59,6 +59,7 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaModelinePlugin,
                                 pluma_modeline_plugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
+                                G_ADD_PRIVATE_DYNAMIC (PlumaModelinePlugin)
                                 G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
                                                                peas_activatable_iface_init))
 
@@ -87,9 +88,7 @@ pluma_modeline_plugin_init (PlumaModelinePlugin *plugin)
 {
 	pluma_debug_message (DEBUG_PLUGINS, "PlumaModelinePlugin initializing");
 
-	plugin->priv = G_TYPE_INSTANCE_GET_PRIVATE (plugin,
-	                                            PLUMA_TYPE_MODELINE_PLUGIN,
-	                                            PlumaModelinePluginPrivate);
+	plugin->priv = pluma_modeline_plugin_get_instance_private (plugin);
 }
 
 static void
@@ -279,10 +278,10 @@ pluma_modeline_plugin_deactivate (PeasActivatable *activatable)
 	for (l = views; l != NULL; l = l->next)
 	{
 		disconnect_handlers (PLUMA_VIEW (l->data));
-		
+
 		modeline_parser_deactivate (GTK_SOURCE_VIEW (l->data));
 	}
-	
+
 	g_list_free (views);
 }
 
@@ -298,8 +297,6 @@ pluma_modeline_plugin_class_init (PlumaModelinePluginClass *klass)
 	object_class->get_property = pluma_modeline_plugin_get_property;
 
 	g_object_class_override_property (object_class, PROP_OBJECT, "object");
-
-	g_type_class_add_private (klass, sizeof (PlumaModelinePluginPrivate));
 }
 
 static void
