@@ -1,6 +1,6 @@
 /*
  * pluma-taglist-plugin.h
- * 
+ *
  * Copyright (C) 2002-2005 - Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /*
- * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a 
- * list of people on the pluma Team.  
- * See the ChangeLog files for a list of changes. 
+ * Modified by the pluma Team, 2002-2005. See the AUTHORS file for a
+ * list of people on the pluma Team.
+ * See the ChangeLog files for a list of changes.
  *
  * $Id$
  */
@@ -42,8 +42,6 @@
 #include <pluma/pluma-window.h>
 #include <pluma/pluma-debug.h>
 
-#define PLUMA_TAGLIST_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PLUMA_TYPE_TAGLIST_PLUGIN, PlumaTaglistPluginPrivate))
-
 struct _PlumaTaglistPluginPrivate
 {
 	GtkWidget *window;
@@ -57,6 +55,7 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaTaglistPlugin,
                                 pluma_taglist_plugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
+                                G_ADD_PRIVATE_DYNAMIC (PlumaTaglistPlugin)
                                 G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
                                                                peas_activatable_iface_init) \
                                                                                             \
@@ -71,7 +70,7 @@ enum {
 static void
 pluma_taglist_plugin_init (PlumaTaglistPlugin *plugin)
 {
-	plugin->priv = PLUMA_TAGLIST_PLUGIN_GET_PRIVATE (plugin);
+	plugin->priv = pluma_taglist_plugin_get_instance_private (plugin);
 
 	pluma_debug_message (DEBUG_PLUGINS, "PlumaTaglistPlugin initializing");
 }
@@ -98,7 +97,7 @@ pluma_taglist_plugin_finalize (GObject *object)
 	pluma_debug_message (DEBUG_PLUGINS, "PlumaTaglistPlugin finalizing");
 
 	free_taglist ();
-	
+
 	G_OBJECT_CLASS (pluma_taglist_plugin_parent_class)->finalize (object);
 }
 
@@ -120,9 +119,9 @@ pluma_taglist_plugin_activate (PeasActivatable *activatable)
 	priv->taglist_panel = pluma_taglist_plugin_panel_new (window, data_dir);
 	g_free (data_dir);
 
-	pluma_panel_add_item_with_icon (side_panel, 
+	pluma_panel_add_item_with_icon (side_panel,
 					priv->taglist_panel,
-					_("Tags"), 
+					_("Tags"),
 					"list-add");
 }
 
@@ -132,14 +131,14 @@ pluma_taglist_plugin_deactivate (PeasActivatable *activatable)
 	PlumaTaglistPluginPrivate *priv;
 	PlumaWindow *window;
 	PlumaPanel *side_panel;
-	
+
 	pluma_debug (DEBUG_PLUGINS);
-	
+
 	priv = PLUMA_TAGLIST_PLUGIN (activatable)->priv;
 	window = PLUMA_WINDOW (priv->window);
 	side_panel = pluma_window_get_side_panel (window);
 
-	pluma_panel_remove_item (side_panel, 
+	pluma_panel_remove_item (side_panel,
 				 priv->taglist_panel);
 }
 
@@ -212,8 +211,6 @@ pluma_taglist_plugin_class_init (PlumaTaglistPluginClass *klass)
 	object_class->get_property = pluma_taglist_plugin_get_property;
 
 	g_object_class_override_property (object_class, PROP_OBJECT, "object");
-
-	g_type_class_add_private (object_class, sizeof (PlumaTaglistPluginPrivate));
 }
 
 static void
