@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
 
@@ -29,8 +29,6 @@
 #include "pluma-tab-label.h"
 #include "pluma-close-button.h"
 
-#define PLUMA_TAB_LABEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), PLUMA_TYPE_TAB_LABEL, PlumaTabLabelPrivate))
-
 /* Signals */
 enum
 {
@@ -59,7 +57,7 @@ struct _PlumaTabLabelPrivate
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (PlumaTabLabel, pluma_tab_label, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (PlumaTabLabel, pluma_tab_label, GTK_TYPE_BOX)
 
 static void
 pluma_tab_label_finalize (GObject *object)
@@ -108,7 +106,7 @@ pluma_tab_label_get_property (GObject    *object,
 }
 
 static void
-close_button_clicked_cb (GtkWidget     *widget, 
+close_button_clicked_cb (GtkWidget     *widget,
 			 PlumaTabLabel *tab_label)
 {
 	g_signal_emit (tab_label, signals[CLOSE_CLICKED], 0, NULL);
@@ -218,7 +216,7 @@ static void
 pluma_tab_label_class_init (PlumaTabLabelClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	
+
 	object_class->finalize = pluma_tab_label_finalize;
 	object_class->set_property = pluma_tab_label_set_property;
 	object_class->get_property = pluma_tab_label_get_property;
@@ -242,8 +240,6 @@ pluma_tab_label_class_init (PlumaTabLabelClass *klass)
 							      PLUMA_TYPE_TAB,
 							      G_PARAM_READWRITE |
 							      G_PARAM_CONSTRUCT_ONLY));
-
-	g_type_class_add_private (object_class, sizeof(PlumaTabLabelPrivate));
 }
 
 static void
@@ -257,7 +253,7 @@ pluma_tab_label_init (PlumaTabLabel *tab_label)
 	GtkWidget *label;
 	GtkWidget *dummy_label;
 
-	tab_label->priv = PLUMA_TAB_LABEL_GET_PRIVATE (tab_label);
+	tab_label->priv = pluma_tab_label_get_instance_private (tab_label);
 
 	tab_label->priv->close_button_sensitive = TRUE;
 
@@ -283,7 +279,7 @@ pluma_tab_label_init (PlumaTabLabel *tab_label)
 			  "clicked",
 			  G_CALLBACK (close_button_clicked_cb),
 			  tab_label);
-			  
+
 	spinner = gtk_spinner_new ();
 	gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
 	tab_label->priv->spinner = spinner;
@@ -330,7 +326,7 @@ pluma_tab_label_set_close_button_sensitive (PlumaTabLabel *tab_label,
 
 	state = pluma_tab_get_state (tab_label->priv->tab);
 
-	gtk_widget_set_sensitive (tab_label->priv->close_button, 
+	gtk_widget_set_sensitive (tab_label->priv->close_button,
 				  tab_label->priv->close_button_sensitive &&
 				  (state != PLUMA_TAB_STATE_CLOSING) &&
 				  (state != PLUMA_TAB_STATE_SAVING)  &&
